/*
 *--- PageMakerCQErrs.h --------------------------------------------------
 * Copyright (c) 1995, Adobe Systems, Inc.  All rights reserved.
 *
 * For PageMaker plug-ins, these are the most common category of errors.
 *
 * $Revision:   1.4  $
 *
 *
 *------------------------------------------------------------------------
 */
#ifndef __PageMakerCQErrs__
#define __PageMakerCQErrs__

#include "PMErrors.h"

enum
{
	CQ_NO_ERR				= 0,
	CQ_SUCCESS				= 0,			// same as SUCCESS.
	CQ_IGNORED				= 0,

	CQ_OPERATION_COMPLETE,					// for occaisions that completion requires a non-zero value.
											// This cannot be used as an error code.
	CQ_DONT_DISCARD = CQ_OPERATION_COMPLETE,	// tell PM not to free the Addition yet
	CQ_DISK_FULL	= 94,				// Disk is full
	
		// These are internal errors that should never be displayed.
	CQ_CTOR_INVALID_ARGS	= CQ_ER_BASE+1,	// 7201: Object constructor failed due to bad args.
	CQ_CTOR_FAILED,							// 7202: General constructor failure.
	CQ_NEW_FAILED,							// 7203: a new failed.
	CQ_BAD_OBJECT,							// 7204: Attempt to use an invalid object.
	CQ_COERCION_FAILED,						// 7205: Type coercion failed.
	CQ_NOT_IMPLEMENTED,						// 7206: unction is not currently implemented.

		// These are exportable errors:
	CQ_BUFFSIZE_TOO_SMALL,					// 7207: buffer size is too small.
	CQ_NSF_MEMORY,							// 7208: Insuffiecient Memory to proceed
	CQ_INVALID_ARGS,						// 7209: one or more invalid arguments. internal, no # in message.
	CQ_NOT_ENOUGH_ARGS,						// 7210: Not enough arguments supplied.
	CQ_BAD_ARG_PACKET,						// 7211:Improper binary argument packet.
	CQ_SYS_FAILED,							// 7212:some system operation failed.
	CQ_FAILURE			= CQ_SYS_FAILED,	// 7212:generalized failure code.
	CQ_DIDNT_HANDLE,						// 7213:operation was not performed.
	CQ_CANT_HANDLE,							// 7214:operation not performed by this module.
	CQ_INVALID_STATE,						// 7215:operation invalid in current module state.
	CQ_RES_NOT_FOUND,						// 7216:resource not found
	CQ_CANT_LOAD_ADD,						// 7217:cannot load Addition library
	CQ_ADD_NOT_FOUND,						// 7218:Addition resource not found
	CQ_ADD_INIT_FAILED,						// 7219:Addition nitialization failed
	CQ_INVAL_INT_VER,						// 7220:Invalid interface version
	CQ_ADDRES_NOT_FOUND,					// 7221:Registration resource not found
	CQ_NO_ARGS,								// 7222:No Arguments supplied.
	CQ_INVALID_CQ_ARG,						// 7223:invalid argument to command or query. takes arg # in message.
	CQ_ADDN_ERR,							// 7224:Error returned from the Addition.
	CQ_ADDN_CANT_ERR,						// 7225:Error from the Addition with "Cant" string.
	CQ_PARS_BAD_CMD,						// 7226:Parser can't regognize command
	CQ_PARS_BAD_ARG,						// 7227:Parser can't parse argument list
	CQ_OLD_CMD,								// 7228:Command is no longer supported
	CQ_INVALID_OBJECTID,					// 7229:Object id. doesn't exist in pub (or on current page(s))	
	CQ_LO_INVALID_MODE,						// 7230:Command or query works only in story editor.
	CQ_SE_INVALID_MODE,						// 7231:Command or query works only in layout view.
	CQ_SEARCH_STATUS,						// 7232:No match found, or search complete.
	CQ_CHANGEALL_STATUS,					// 7233:No matches found. Search complete.
	CQ_SPELL_STATUS,						// 7234:No spelling errors detected, or spelling check complete.
	CQ_NOPDATA,								// 7235:No private data found
	CQ_INVALID_TARGET,						// 7236:Specified target does not exist
	CQ_PDATA_ALREADY_EXISTS,				// 7237:Private data already exists for specified target
	CQ_INVALID_CLASS,						// 7238:Invalid target class
	CQ_STRING_TOO_BIG,						// 7239:Private data string too big
	CQ_NO_INITIAL_SEARCH,					// 7240:Command must follow find or change command
	CQ_INITDICTERROR,						// 7241:Error initializing language dictionary
	CQ_DUPWORDDICTERROR,					// 7242:Word is already in user dictionary
	CQ_ADDTODICTERROR,						// 7243:Unable to add new word to user dictionary
	CQ_NOWORDDICTERROR,						// 7244:Word was not found in user dictionary
	CQ_ACCESSDICTERROR,						// 7245:Error accessing language dictionary
	CQ_OPENDICTERROR,						// 7246:Could not open user dictionary
	CQ_MIXED_LOCKERROR,						// 7247:Could not group locked and unlocked segments
	CQ_INTF_NOTIMPLEMENTED,					// 7248:Interface is not impelemented.
	CQ_SEEK_ERROR,							// 7249:Error on seeking
	CQ_PDATA_NOT_OPEN,						// 7250:Requested private data has not been opened
	CQ_ACCESS_DENIED,							// 7251:Access denied
	CQ_PDATA_ALREADY_OPEN,					// 7252:Private data has already been opened
	CQ_PRNTSTRM_WRONG_TIME,					// 7253:PSA - tried to access print stream at a wrong time
	CQ_PRNTSTRM_NOT_SETUP,					// 7254:PSA - is not before/after job/page setup
	CQ_PRNTSTRM_NOT_PROLOG,					// 7255:PSA - is not before/after prolog 
	CQ_PRNTSTRM_NOT_ENOUGH_VM,				// 7256:PSA - insufficient VM for dict
	CQ_PRNTSTRM_NOT_A_COMMMENT,				// 7257:PSA - string sent is not a valid PS comment 
	CQ_ACTIVE_LAYER_CANTWRITE,				// 7258:Active layer is locked or hidden.
	CQ_INVALID_EVENTID,						// 7259:Invalid Event ID for PM Register/unregister
	CQ_OBJACC_NO_MORE_OBJECTS,				// 7260:ObjAcc - no more objects on page
	CQ_OBJACC_OBJ_NOT_FOUND,				// 7261:ObjAcc - requested object not found 
	CQ_OBJACC_OBJ_NOT_LINKED,				// 7262:ObjAcc - given object is not linked (for GetObjLinkInfo()) 
	CQ_OBJACC_INVALID_PAGENUM,				// 7263:ObjAcc - given page number is not valid
	CQ_NO_LINEBREAK_INFO,					// 7264:CIText - no linebreak information for given story and line number
	CQ_NO_MORE_ILGS,						// 7265:CIText - no more ILGs associated with this story
	CQ_SCRIPTABORT,							// 7266:Script Palette - user requested script to be aborted
	CQ_IMSAVE_NOT_INITIALIZED,				// 7267:CIMSAVE - not intialized
	CQ_OBJACC_TURNPAGE_FAIL,				// 7268:ObjAcc - cant turn page
	CQ_FRAME_FAILURE,						// 7269:CIFrame - general frame failure code
	CQ_FRAME_INVALID_SHAPE,					// 7270:CIFrame - Bad shape for frame
	CQ_FRAME_CANNOT_OPEN_TABLE,				// 7271:CIFrame - Cannot open table?
	CQ_FRAME_OBJ_NOT_FOUND,					// 7272:CIFrame - Frame not found
	CQ_FRAME_EMPTY_FRAME,					// 7273:CIFrame - Frame is not supposed to be empty
	CQ_FRAME_NOT_EMPTY_FRAME,				// 7274:CIFrame - Frame is not supposed to be full
	CQ_FRAME_NO_MORE_LINKS,					// 7275:CIFrame - Frame has no next/prev link
	CQ_FRAME_CANNOT_LINK_FRAMES,			// 7276:CIFrame - Specified frames cannot be linked
	CQ_IMGACC_INVALID_OBJTYPE,				// 7277:CImagAcc - Object must be a bitmap type.
	// Insert new errors here:
	
	CQ_LAST_ERR								// Last CQ Error               // Last CQ Error.
};

enum CQLocation 
{
	CQ_XADN = CQ_AC_BASE+1,                                 //  Errors from the Addition XComponent.
	CQ_XAE,                                                                 //  Errors from the Apple IAC XComponent.
	CQ_XDDE,                                                                //  Errors from the DDE XComponent.
	CQ_XPRS,                                                                //  Errors from the XParser class.
	CQ_XIPS,                                                                //  Errors from the Internal XParser.
	CQ_XDTA,                                                                //  Errors from the XPMData object.
	CQ_QWRY,                                                                //  Errors from the Query Services.
	CQ_CMND,                                                                //  Errors from the Command Services.
	CQ_XMEM,                                                                //      Errors from the XMemory object.
	CQ_ADDREG                                                               //      Errors in registering Addition.
};


#endif

// end of PageMakerCQErrs.h


